MethodChannelRxConnectivityChecker class

An implementation of RxConnectivityCheckerPlatform that uses method channels.

Inheritance

Properties

eventChannel EventChannel
The event channel used to listen for continuous network changes. The name MUST match the one defined in Android (Kotlin) and iOS (Swift).
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
platformStatusStream Stream<String>
Exposes the native connectivity events as a Dart stream.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Retrieves the running platform's version string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited